<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikal/horisontal</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Tilpasset</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Rutenett</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Slutt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>På entitet</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Vinkelrett</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangerende</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Senter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Midtpunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Skjæringspunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referanse</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Avstand</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Ugyldig</translation>
    </message>
</context>
</TS>
